Rename the PolicyManager to UpdateManager.

This change renames the PolicyManager class, directory, tests, etc,
to avoid confusion with libpolicy and its classes.

BUG=chromium:373551
TEST=emerged on link.
CQ-DEPEND=CL:I43081673c7ba409f02273197da7915537bde39c6

Change-Id: Iffa76caa3b95ecbbdba87ab01006d1d8ce35a27f
Reviewed-on: https://chromium-review.googlesource.com/201876
Tested-by: Alex Deymo <deymo@chromium.org>
Reviewed-by: David Zeuthen <zeuthen@chromium.org>
Commit-Queue: Alex Deymo <deymo@chromium.org>
diff --git a/system_state.h b/system_state.h
index a9e3c02..b008095 100644
--- a/system_state.h
+++ b/system_state.h
@@ -7,11 +7,11 @@
 
 class MetricsLibraryInterface;
 
-namespace chromeos_policy_manager {
+namespace chromeos_update_manager {
 
-class PolicyManager;
+class UpdateManager;
 
-}  // namespace chromeos_policy_manager
+}  // namespace chromeos_update_manager
 
 namespace policy {
 
@@ -84,8 +84,8 @@
   // Returns a pointer to the P2PManager singleton.
   virtual P2PManager* p2p_manager() = 0;
 
-  // Returns a pointer to the PolicyManager singleton.
-  virtual chromeos_policy_manager::PolicyManager* policy_manager() = 0;
+  // Returns a pointer to the UpdateManager singleton.
+  virtual chromeos_update_manager::UpdateManager* update_manager() = 0;
 
   // If true, this is the first instance of the update engine since the system
   // restarted. Important for tracking whether you are running instance of the